@@ -14,16 +14,12 @@ oldsecs = time()
 maxstate = g.numstates() - 1
 
 for row in xrange(r.top, r.top + r.height):
-   # if large selection then give some indication of progress
-   newsecs = time()
-   if newsecs - oldsecs >= 1.0:
-      oldsecs = newsecs
-      g.update()
-
-   # also allow keyboard interaction
-   g.dokey( g.getkey() )
-
-   for col in xrange(r.left, r.left + r.width):
-      g.setcell(col, row, maxstate - g.getcell(col, row))
+    # if large selection then give some indication of progress
+    newsecs = time()
+    if newsecs - oldsecs >= 1.0:
+        oldsecs = newsecs
+        g.update()
+    for col in xrange(r.left, r.left + r.width):
+        g.setcell(col, row, maxstate - g.getcell(col, row))
 
 if not r.visible(): g.fitsel()
