@@ -20,18 +20,20 @@ def slideshow ():
                 # ignore hidden files (like .DS_Store on Mac)
                 pass
             else:
+                g.new("")
+                g.setalgo("QuickLife")      # nicer to start from this algo
                 fullname = join(root, name)
-                g.open(fullname, False)       # don't add file to Open/Run Recent submenu
+                g.open(fullname, False)     # don't add file to Open/Run Recent submenu
                 g.update()
-                if name.endswith(".pl") or name.endswith(".py"):
+                if name.endswith(".lua") or name.endswith(".py"):
                     # reshow message in case it was changed by script
                     g.show(message)
 
                 while True:
                     event = g.getevent()
                     if event == "key space none": break
-                    g.doevent(event)           # allow keyboard/mouse interaction
-                    sleep(0.01)                # avoid hogging cpu
+                    g.doevent(event)        # allow keyboard/mouse interaction
+                    sleep(0.01)             # avoid hogging cpu
 
     # if all patterns have been displayed then restore original algo and rule
     # (don't do this if user hits escape in case they want to explore pattern)
@@ -46,8 +48,7 @@ oldstatus = g.setoption("showstatusbar", True)
 oldtoolbar = g.setoption("showtoolbar", False)
 oldlayerbar = g.setoption("showlayerbar", False)
 oldeditbar = g.setoption("showeditbar", False)
-oldscripts = g.setoption("showscripts", False)
-oldpatterns = g.setoption("showpatterns", False)
+oldfiles = g.setoption("showfiles", False)
 
 try:
     slideshow()
@@ -60,5 +61,4 @@ finally:
     g.setoption("showtoolbar", oldtoolbar)
     g.setoption("showlayerbar", oldlayerbar)
     g.setoption("showeditbar", oldeditbar)
-    g.setoption("showscripts", oldscripts)
-    g.setoption("showpatterns", oldpatterns)
+    g.setoption("showfiles", oldfiles)
