@@ -1,26 +1,6 @@
-                        /*** /
+// This file is part of Golly.
+// See docs/License.html for the copyright notice.
 
-This file is part of Golly, a Game of Life Simulator.
-Copyright (C) 2013 Andrew Trevorrow and Tomas Rokicki.
-
-This program is free software; you can redistribute it and/or
-modify it under the terms of the GNU General Public License
-as published by the Free Software Foundation; either version 2
-of the License, or (at your option) any later version.
-
-This program is distributed in the hope that it will be useful,
-but WITHOUT ANY WARRANTY; without even the implied warranty of
-MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-GNU General Public License for more details.
-
-You should have received a copy of the GNU General Public License
-along with this program; if not, write to the Free Software
-Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
-
- Web site:  http://sourceforge.net/projects/golly
- Authors:   rokicki@gmail.com  andrew@trevorrow.com
-
-                        / ***/
 #include "bigint.h"
 #include <cstdlib>
 #include <string.h>
@@ -44,12 +24,6 @@ int bigint::sepcount = 3 ;
 /**
  *   Routines.
  */
-bigint::bigint() {
-   v.i = 1 ;
-}
-bigint::bigint(int i) {
-   fromint(i) ;
-}
 bigint::bigint(G_INT64 i) {
    if (i <= INT_MAX && i >= INT_MIN)
       fromint((int)i) ;
@@ -73,7 +47,7 @@ bigint::bigint(const char *s) {
       if (x < 31)
          fromint(1 << x) ;
       else {
-         int sz = 2 + (x + 1) / 31 ;
+         int sz = 2 + int((x + 1) / 31) ;
          int asz = sz ;
          while (asz & (asz - 1))
             asz &= asz - 1 ;
@@ -143,6 +117,20 @@ bigint::~bigint() {
    if (0 == (v.i & 1))
       delete [] v.p ;
 }
+bigint::bigint(const bigint &a, const bigint &b, const bigint &c, const bigint &d) {
+   const int checkmask = 0xf0000001 ;
+   if ((a.v.i & checkmask) == 1 && (b.v.i & checkmask) == 1 &&
+       (c.v.i & checkmask) == 1 && (d.v.i & checkmask) == 1) {
+      // hot path
+      v.i = a.v.i + b.v.i + c.v.i + d.v.i - 3 ;
+      return ;
+   }
+   v.i = 1 ;
+   *this = a ;
+   *this += b ;
+   *this += c ;
+   *this += d ;
+}
 const char *bigint::tostring(char sep) const {
    int lenreq = 32 ;
    if ((v.i & 1) == 0)
