@@ -1621,7 +1621,7 @@ node *hlifealgo::runpattern() {
       n->res = 0 ;
       halvesdone = 0 ;
    }
-   if (poller->isInterrupted())
+   if (poller->isInterrupted() || softinterrupt)
       return 0 ; // indicate it was interrupted
    n = popzeros(n2) ;
    generation += pow2step ;
