@@ -1,26 +1,6 @@
-                        /*** /
+// This file is part of Golly.
+// See docs/License.html for the copyright notice.
 
-This file is part of Golly, a Game of Life Simulator.
-Copyright (C) 2013 Andrew Trevorrow and Tomas Rokicki.
-
-This program is free software; you can redistribute it and/or
-modify it under the terms of the GNU General Public License
-as published by the Free Software Foundation; either version 2
-of the License, or (at your option) any later version.
-
-This program is distributed in the hope that it will be useful,
-but WITHOUT ANY WARRANTY; without even the implied warranty of
-MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-GNU General Public License for more details.
-
-You should have received a copy of the GNU General Public License
-along with this program; if not, write to the Free Software
-Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
-
- Web site:  http://sourceforge.net/projects/golly
- Authors:   rokicki@gmail.com  andrew@trevorrow.com
-
-                        / ***/
 #include "lifealgo.h"
 #include "util.h"       // for lifestatus
 #include "string.h"
@@ -526,7 +506,7 @@ void lifealgo::JoinTwistedAndShiftedEdges()
     }
 }
 
-void lifealgo::JoinShiftedEdges(int hshift, int vshift)  // horizontal and vertical shifts
+void lifealgo::JoinShiftedEdges()
 {
     // set grid edges
     int gl = gridleft.toint();
@@ -799,7 +779,7 @@ bool lifealgo::CreateBorderCells()
         
     } else if (hshift != 0 || vshift != 0) {
         // torus with horizontal or vertical shift
-        JoinShiftedEdges(hshift, vshift);
+        JoinShiftedEdges();
         
     } else {
         // unshifted torus or infinite tube
@@ -896,6 +876,14 @@ bool lifealgo::DeleteBorderCells()
     return true;
 }
 
+void lifealgo::getcells(unsigned char *buf, int x, int y, int w, int h) {
+   viewport vp(w, h) ;
+   vp.setpositionmag(x+(w>>1), y+(h>>1), 0) ;
+   staterender hsr(buf, w, h) ;
+   memset(buf, 0, w*h) ;
+   draw(vp, hsr) ;
+}
+
 // -----------------------------------------------------------------------------
 
 int staticAlgoInfo::nextAlgoId = 0 ;
