@@ -1,26 +1,6 @@
-                        /*** /
+// This file is part of Golly.
+// See docs/License.html for the copyright notice.
 
-This file is part of Golly, a Game of Life Simulator.
-Copyright (C) 2013 Andrew Trevorrow and Tomas Rokicki.
-
-This program is free software; you can redistribute it and/or
-modify it under the terms of the GNU General Public License
-as published by the Free Software Foundation; either version 2
-of the License, or (at your option) any later version.
-
-This program is distributed in the hope that it will be useful,
-but WITHOUT ANY WARRANTY; without even the implied warranty of
-MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-GNU General Public License for more details.
-
-You should have received a copy of the GNU General Public License
-along with this program; if not, write to the Free Software
-Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
-
- Web site:  http://sourceforge.net/projects/golly
- Authors:   rokicki@gmail.com  andrew@trevorrow.com
-
-                        / ***/
 /**
  *   Encapsulate a class capable of rendering a life universe.
  *   Note that we only use blitbit calls (no setpixel).
@@ -44,20 +24,39 @@ Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 #define LIFERENDER_H
 class liferender {
 public:
-   liferender() {}
+   liferender() : juststate(0) {}
+   liferender(int state) : juststate(state) {}
+   int justState() { return juststate ; }
    virtual ~liferender() ;
 
+   // First two methods (pixblit/getcolors) only called for normal
+   // display renderers.  For "getstate" renderers, these will never
+   // be called.
    // pixblit is used to draw a pixel map by passing data in two formats:
    // If pmscale == 1 then pm data contains 4*w*h bytes where each
    // byte quadruplet contains the RGBA values for the corresponding pixel.
    // If pmscale > 1 then pm data contains (w/pmscale)*(h/pmscale) bytes
    // where each byte is a cell state (0..255).  This allows the rendering
    // code to display either icons or colors.
-   virtual void pixblit(int x, int y, int w, int h, unsigned char* pm, int pmscale) = 0;
+   virtual void pixblit(int x, int y, int w, int h, unsigned char* pm, int pmscale) ;
 
    // the drawing code needs access to the current layer's colors,
    // and to the transparency values for dead pixels and live pixels
    virtual void getcolors(unsigned char** r, unsigned char** g, unsigned char** b,
-                          unsigned char* dead_alpha, unsigned char* live_alpha) = 0;
+                          unsigned char* dead_alpha, unsigned char* live_alpha) ;
+   // for state renderers, this just copies the cell state; no scaling is
+   // supported.  Only called for juststate renderers.
+   virtual void stateblit(int x, int y, int w, int h, unsigned char* pm) ;
+private:
+   int juststate ;
+} ;
+class staterender : public liferender {
+public:
+   staterender(unsigned char *_buf, int _vw, int _vh) :
+               liferender(1), buf(_buf), vw(_vw), vh(_vh) {}
+   virtual void stateblit(int x, int y, int w, int h, unsigned char* pm) ;
+private:
+   unsigned char *buf ;
+   int vw, vh ;
 } ;
 #endif
