@@ -359,15 +359,28 @@ int ltlalgo::getcell(int x, int y)
 
 int ltlalgo::nextcell(int x, int y, int& v)
 {
-    // check if x,y is outside grid
-    if (x < gleft || x > gright) return -1;
+    if (population == 0) return -1;
+
+    // check if y is outside grid
     if (y < gtop || y > gbottom) return -1;
     
+    // check if x is outside right edge
+    if (x > gright) return -1;
+
+    // init distance
+    int d = 0;
+    
+    // if x is outside left edge then set it to gleft and increase d
+    // (this is necessary in case the user makes a selection outside
+    // gleft when the universe is unbounded)
+    if (x < gleft) {
+        d = gleft - x;
+        x = gleft;
+    }
+    
     // get x,y cell in currgrid
     unsigned char* cellptr = currgrid + (y - gtop) * outerwd + (x - gleft);
     
-    // init distance
-    int d = 0;
     do {
         v = *cellptr;
         if (v > 0) return d;    // found a non-zero cell
@@ -668,7 +681,7 @@ void ltlalgo::faster_Moore_bounded2(int mincol, int minrow, int maxcol, int maxr
     int rowcount = 0;
 
     // compute 4 cell offset
-    int offset = (4 - ((long)cellptr & 3)) & 3;
+    int offset = (4 - ((g_uintptr_t)cellptr & 3)) & 3;
     if (offset > width) offset = width;
 
     // process in 4 cell chunks
@@ -720,7 +733,7 @@ void ltlalgo::faster_Moore_bounded2(int mincol, int minrow, int maxcol, int maxr
         rowcount = 0;
 
         // compute 4 cell offset
-        offset = (4 - ((long)cellptr & 3)) & 3;
+        offset = (4 - ((g_uintptr_t)cellptr & 3)) & 3;
         if (offset > width) offset = width;
 
         // process in 4 cell chunks
@@ -1110,7 +1123,7 @@ void ltlalgo::faster_Moore_unbounded2(int mincol, int minrow, int maxcol, int ma
     int rowcount = 0;
 
     // compute 4 cell offset
-    int offset = (4 - ((long)cellptr & 3)) & 3;
+    int offset = (4 - ((g_uintptr_t)cellptr & 3)) & 3;
     if (offset > width) offset = width;
 
     // process in 4 cell chunks
@@ -1162,7 +1175,7 @@ void ltlalgo::faster_Moore_unbounded2(int mincol, int minrow, int maxcol, int ma
         rowcount = 0;
 
         // compute 4 cell offset
-        offset = (4 - ((long)cellptr & 3)) & 3;
+        offset = (4 - ((g_uintptr_t)cellptr & 3)) & 3;
         if (offset > width) offset = width;
 
         // process in 4 cell chunks
@@ -2186,7 +2199,7 @@ const char *ltlalgo::setrule(const char *s)
     if (r < 1) return "R value is too small";
     int r2 = r*r+r ;
     if (r > MAXRANGE) return "R value is too big";
-    if (c < 0 || c > 255) return "C value must be from 0 to 255";
+    if (c < 0 || c > 256) return "C value must be from 0 to 256";
     if (m < 0 || m > 1) return "M value must be 0 or 1";
     if (s1 > s2) return "S minimum must be <= S maximum";
     if (b1 > b2) return "B minimum must be <= B maximum";
@@ -2204,6 +2217,7 @@ const char *ltlalgo::setrule(const char *s)
        }
        maxn = cnt ;
     }
+    maxn -= (1 - m);    // adjust max neighbors by middle cell setting
     if (s1 < 0 || s1 > maxn || s2 < 0 || s2 > maxn) return "S value must be from 0 to max neighbors";
     if (b1 < 0 || b1 > maxn || b2 < 0 || b2 > maxn) return "B value must be from 0 to max neighbors";
     if (s[endpos] != 0 && s[endpos] != ':') return "bad suffix";
@@ -2252,9 +2266,9 @@ const char *ltlalgo::setrule(const char *s)
     // the given rule is valid
     int oldrange = range;
     char oldtype = ntype;
+    int scount = c;
     range = r;
     rangec = r2;
-    scount = c;
     totalistic = m;
     minS = s1;
     maxS = s2;
@@ -2262,14 +2276,16 @@ const char *ltlalgo::setrule(const char *s)
     maxB = b2;
     ntype = n;
     topology = t;
+    
     if (shape)
-       free(shape) ;
+        free(shape) ;
     shape = (int *)calloc(sizeof(int), 2*r+1) ;
-    for (int i=0; i<2*r+1; i++)
-       shape[i] = tshape[i] ;
+    for (int i=0; i<2*r+1; i++) {
+        shape[i] = tshape[i] ;
+    }
     // set the grid_type so the GUI code can display circles or diamonds in icon mode
-// no circular grid, so adopt a square grid for now
-#define CIRC_GRID SQUARE_GRID
+    // (no circular grid, so adopt a square grid for now)
+    #define CIRC_GRID SQUARE_GRID
     grid_type = ntype == 'M' ? SQUARE_GRID : (ntype == 'N' ? VN_GRID : CIRC_GRID) ;
     
     if (suffix) {
