@@ -90,7 +90,7 @@ struct brick { /* 64 bytes */
 struct tile { /* 32 bytes */
    struct brick *b[4] ;
    short c[6] ;
-   long flags ;
+   int flags ;
 } ;
 /*
  *   Supertiles hold pointers to eight subtiles, which can either be 
@@ -251,7 +251,7 @@ private:
    void allsub(vector<supertile*> &src, vector<supertile*> &dst, int lev) ;
    int gethbitsfromleaves(vector<supertile *> v) ;
    int getvbitsfromleaves(vector<supertile *> v) ;
-   int markglobalchange(supertile *, int) ;
+   supertile *markglobalchange(supertile *, int, int &) ;
    void markglobalchange() ; // call if the rule changes
    /* data elements */
    int min, max, rootlev ;
