@@ -1,26 +1,6 @@
-                        /*** /
+// This file is part of Golly.
+// See docs/License.html for the copyright notice.
 
-This file is part of Golly, a Game of Life Simulator.
-Copyright (C) 2013 Andrew Trevorrow and Tomas Rokicki.
-
-This program is free software; you can redistribute it and/or
-modify it under the terms of the GNU General Public License
-as published by the Free Software Foundation; either version 2
-of the License, or (at your option) any later version.
-
-This program is distributed in the hope that it will be useful,
-but WITHOUT ANY WARRANTY; without even the implied warranty of
-MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-GNU General Public License for more details.
-
-You should have received a copy of the GNU General Public License
-along with this program; if not, write to the Free Software
-Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
-
- Web site:  http://sourceforge.net/projects/golly
- Authors:   rokicki@gmail.com  andrew@trevorrow.com
-
-                        / ***/
 #include "qlifealgo.h"
 #include <cstring>
 #include <cstdlib>
@@ -39,6 +19,9 @@ static unsigned char pixbuf[bmsize*bmsize*4];
 static unsigned char deadr, deadg, deadb, deada;
 static unsigned char liver, liveg, liveb, livea;
 
+// rowett: RGBA view of cell states
+static unsigned int liveRGBA, deadRGBA;
+
 void qlifealgo::renderbm(int x, int y) {
    renderbm(x, y, bmsize, bmsize) ;
 }
@@ -57,36 +40,43 @@ void qlifealgo::renderbm(int x, int y, int xsize, int ysize) {
    }
    ry = uviewh - ry - rh ;
 
-   if (pmag > 1) {
+   unsigned char *bigptr = bigbuf;
+   if (renderer->justState() || pmag > 1) {
       // convert each bigbuf byte into 8 bytes of state data
-      int j = 0;
+      unsigned char *pixptr = pixbuf;
+
       for (int i = 0; i < ibufsize * 4; i++) {
-         int byte = bigbuf[i];
-         for (int bit = 128; bit > 0; bit >>= 1) {
-            pixbuf[j++] = (byte & bit) ? 1 : 0;
-         }
+         unsigned char byte = *bigptr++;
+         *pixptr++ = (byte & 128) ? 1 : 0;
+         *pixptr++ = (byte & 64) ? 1 : 0;
+         *pixptr++ = (byte & 32) ? 1 : 0;
+         *pixptr++ = (byte & 16) ? 1 : 0;
+         *pixptr++ = (byte & 8) ? 1 : 0;
+         *pixptr++ = (byte & 4) ? 1 : 0;
+         *pixptr++ = (byte & 2) ? 1 : 0;
+         *pixptr++ = (byte & 1);    // no condition needed
       }
    } else {
       // convert each bigbuf byte into 32 bytes of pixel data (8 * RGBA)
-      int j = 0;
+      // get RGBA view of pixel buffer
+      unsigned int *pixptr = (unsigned int *)pixbuf;
+
       for (int i = 0; i < ibufsize * 4; i++) {
-         int byte = bigbuf[i];
-         for (int bit = 128; bit > 0; bit >>= 1) {
-            if (byte & bit) {
-               pixbuf[j++] = liver;
-               pixbuf[j++] = liveg;
-               pixbuf[j++] = liveb;
-               pixbuf[j++] = livea;
-            } else {
-               pixbuf[j++] = deadr;
-               pixbuf[j++] = deadg;
-               pixbuf[j++] = deadb;
-               pixbuf[j++] = deada;
-            }
-         }
+         unsigned char byte = *bigptr++;
+         *pixptr++ = (byte & 128) ? liveRGBA : deadRGBA;
+         *pixptr++ = (byte & 64) ? liveRGBA : deadRGBA;
+         *pixptr++ = (byte & 32) ? liveRGBA : deadRGBA;
+         *pixptr++ = (byte & 16) ? liveRGBA : deadRGBA;
+         *pixptr++ = (byte & 8) ? liveRGBA : deadRGBA;
+         *pixptr++ = (byte & 4) ? liveRGBA : deadRGBA;
+         *pixptr++ = (byte & 2) ? liveRGBA : deadRGBA;
+         *pixptr++ = (byte & 1) ? liveRGBA : deadRGBA;
       }
    }
-   renderer->pixblit(rx, ry, rw, rh, pixbuf, pmag);
+   if (renderer->justState())
+      renderer->stateblit(rx, ry, rw, rh, pixbuf) ;
+   else
+      renderer->pixblit(rx, ry, rw, rh, pixbuf, pmag);
 
    memset(bigbuf, 0, sizeof(ibigbuf)) ;
 }
@@ -461,16 +451,32 @@ void qlifealgo::draw(viewport &viewarg, liferender &renderarg) {
    memset(bigbuf, 0, sizeof(ibigbuf)) ;
    renderer = &renderarg ;
 
-   // AKT: get cell colors and alpha values for dead and live pixels
-   unsigned char *r, *g, *b;
-   renderer->getcolors(&r, &g, &b, &deada, &livea);
-   deadr = r[0];
-   deadg = g[0];
-   deadb = b[0];
-   liver = r[1];
-   liveg = g[1];
-   liveb = b[1];
+   if (!renderer->justState()) {
+      // AKT: get cell colors and alpha values for dead and live pixels
+      unsigned char *r, *g, *b;
+      renderer->getcolors(&r, &g, &b, &deada, &livea);
+      deadr = r[0];
+      deadg = g[0];
+      deadb = b[0];
+      liver = r[1];
+      liveg = g[1];
+      liveb = b[1];
 
+      // create RGBA live color
+      unsigned char *colptr = (unsigned char *)&liveRGBA;
+      *colptr++ = liver;
+      *colptr++ = liveg;
+      *colptr++ = liveb;
+      *colptr++ = livea;
+
+      // create RGBA dead color
+      colptr = (unsigned char *)&deadRGBA;
+      *colptr++ = deadr;
+      *colptr++ = deadg;
+      *colptr++ = deadb;
+      *colptr++ = deada;
+   }
+      
    view = &viewarg ;
    uvieww = view->getwidth() ;
    uviewh = view->getheight() ;
