@@ -1,26 +1,6 @@
-                        /*** /
+// This file is part of Golly.
+// See docs/License.html for the copyright notice.
 
-This file is part of Golly, a Game of Life Simulator.
-Copyright (C) 2013 Andrew Trevorrow and Tomas Rokicki.
-
-This program is free software; you can redistribute it and/or
-modify it under the terms of the GNU General Public License
-as published by the Free Software Foundation; either version 2
-of the License, or (at your option) any later version.
-
-This program is distributed in the hope that it will be useful,
-but WITHOUT ANY WARRANTY; without even the implied warranty of
-MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-GNU General Public License for more details.
-
-You should have received a copy of the GNU General Public License
-along with this program; if not, write to the Free Software
-Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
-
- Web site:  http://sourceforge.net/projects/golly
- Authors:   rokicki@gmail.com  andrew@trevorrow.com
-
-                        / ***/
 #include "ruletable_algo.h"
 
 #include "util.h"      // for lifegetuserrules, lifegetrulesdir, lifewarning
@@ -441,6 +421,12 @@ string ruletable_algo::LoadRuleTable(string rule)
                return oss.str();
             }
             output = c-'0';
+            if (output >= n_states)     // AKT: avoid later crash in PackTransition
+            {
+                ostringstream oss;
+                oss << "Error reading " << full_filename << " on line " << lineno << ": " << line << " - state out of range";
+                return oss.str();
+            }
             transition_table.push_back(make_pair(inputs,output));
          }
          else // transition line with commas
