@@ -1,26 +1,5 @@
-/*** /
-
- This file is part of Golly, a Game of Life Simulator.
- Copyright (C) 2013 Andrew Trevorrow and Tomas Rokicki.
-
- This program is free software; you can redistribute it and/or
- modify it under the terms of the GNU General Public License
- as published by the Free Software Foundation; either version 2
- of the License, or (at your option) any later version.
-
- This program is distributed in the hope that it will be useful,
- but WITHOUT ANY WARRANTY; without even the implied warranty of
- MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- GNU General Public License for more details.
-
- You should have received a copy of the GNU General Public License
- along with this program; if not, write to the Free Software
- Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
-
- Web site:  http://sourceforge.net/projects/golly
- Authors:   rokicki@gmail.com  andrew@trevorrow.com
-
- / ***/
+// This file is part of Golly.
+// See docs/License.html for the copyright notice.
 
 package net.sf.golly;
 
@@ -33,13 +12,13 @@ import java.net.HttpURLConnection;
 import java.net.MalformedURLException;
 import java.net.URL;
 
+import android.app.Activity;
 import android.content.Intent;
 import android.os.Bundle;
 import android.os.Handler;
-import android.os.Looper;
-import android.os.Message;
 import android.support.v4.app.NavUtils;
 import android.util.DisplayMetrics;
+// import android.util.Log;
 import android.view.Menu;
 import android.view.MenuItem;
 import android.view.View;
@@ -50,13 +29,14 @@ import android.widget.LinearLayout;
 import android.widget.ProgressBar;
 import android.widget.Toast;
 
-public class HelpActivity extends BaseActivity {
+public class HelpActivity extends Activity {
 
     // see jnicalls.cpp for these native routines:
     private static native void nativeClassInit();   // this MUST be static
     private native void nativeCreate();             // the rest must NOT be static
     private native void nativeDestroy();
     private native void nativeGetURL(String url, String pageurl);
+    private native void nativeProcessDownload(String filepath);
     private native void nativeUnzipFile(String zippath);
     private native boolean nativeDownloadedFile(String url);
 
@@ -121,7 +101,12 @@ public class HelpActivity extends BaseActivity {
             return false;
         }
         
-        @Override  
+        @Override
+        public void onReceivedError(WebView webview, int errorCode, String description, String failingUrl) {
+            Toast.makeText(HelpActivity.this, "Web error! " + description, Toast.LENGTH_SHORT).show();
+        }
+        
+        @Override
         public void onPageFinished(WebView webview, String url) {
             super.onPageFinished(webview, url);
             
@@ -135,7 +120,7 @@ public class HelpActivity extends BaseActivity {
 
             // need URL of this page for relative "get:" links
             pageurl = gwebview.getUrl();
-            // Log.i("URL", pageurl);
+            // Log.i("onPageFinished URL", pageurl);
         }  
     }
 
@@ -151,6 +136,7 @@ public class HelpActivity extends BaseActivity {
     // -----------------------------------------------------------------------------
     
     private void editFile(String filepath) {
+        BaseApp baseapp = (BaseApp)getApplicationContext();
         // let user read/edit given file
         if (filepath.startsWith("Supplied/")) {
             // read contents of supplied .rule file into a string
@@ -212,6 +198,9 @@ public class HelpActivity extends BaseActivity {
         
         // JavaScript is used to detect device type
         gwebview.getSettings().setJavaScriptEnabled(true);
+
+        // no need???
+        // gwebview.getSettings().setDomStorageEnabled(true);
         
         DisplayMetrics metrics = getResources().getDisplayMetrics();
         // my Nexus 7 has a density of 320
@@ -219,7 +208,7 @@ public class HelpActivity extends BaseActivity {
             // use bigger font size for high density screens (default size is 16)
             gwebview.getSettings().setDefaultFontSize(24);
         }
-        
+
         if (firstcall) {
             firstcall = false;
             backbutton.setEnabled(false);
@@ -255,20 +244,23 @@ public class HelpActivity extends BaseActivity {
     protected void onResume() {
         super.onResume();
         gwebview.onResume();
-        
+
         // restore scroll position and back/forward history
         if (webbundle != null && !restarted) {
             gwebview.restoreState(webbundle);
         }
         restarted = false;
-        
+
         // check for messages sent by other activities
         Intent intent = getIntent();
         String filepath = intent.getStringExtra(SHOWHELP_MESSAGE);
         if (filepath != null) {
+            // replace any spaces with %20
+            filepath = filepath.replaceAll(" ", "%20");
+            // Log.i("onResume filepath", filepath);
             gwebview.loadUrl("file://" + filepath);
         } else {
-            gwebview.reload();
+            // no need: gwebview.reload();
         }
     }
 
@@ -335,6 +327,7 @@ public class HelpActivity extends BaseActivity {
     // -----------------------------------------------------------------------------
     
     private void showContentsPage() {
+        BaseApp baseapp = (BaseApp)getApplicationContext();
         // display html data in supplieddir/Help/index.html
         String fullpath = baseapp.supplieddir.getAbsolutePath() + "/Help/index.html";
         File htmlfile = new File(fullpath);
@@ -395,8 +388,7 @@ public class HelpActivity extends BaseActivity {
             }
             
             long starttime = System.nanoTime();
-            
-            // Log.i("downloadURL: ", urlstring);
+            // Log.i("downloadURL", urlstring);
             URL url = new URL(urlstring);
             HttpURLConnection connection = (HttpURLConnection) url.openConnection();
             connection.setAllowUserInteraction(false);
@@ -429,12 +421,14 @@ public class HelpActivity extends BaseActivity {
                 // show proglayout only if download takes more than 1 second
                 if (System.nanoTime() - starttime > 1000000000L) {
                     runOnUiThread(new Runnable() {
+                        @Override
                         public void run() {
                             proglayout.setVisibility(LinearLayout.VISIBLE);
                         }
                     });
                     starttime = Long.MAX_VALUE; // only show it once
                 }
+
                 if (cancelled) break;
             }
             outstream.close();
@@ -452,46 +446,39 @@ public class HelpActivity extends BaseActivity {
     // -----------------------------------------------------------------------------
 
     private String dresult;
-    
-    static class LooperInterrupter extends Handler {
-    	public void handleMessage(Message msg) {
-            throw new RuntimeException();
-        }
-    }
-    
+
     // this method is called from C++ code (see jnicalls.cpp)
-    private String DownloadFile(String urlstring, String filepath) {
-        // we cannot do network connections on main thread, so we do the
-        // download on a new thread, but we have to wait for it to finish
-        final Handler handler = new LooperInterrupter();
-        
+    private void DownloadFile(String urlstring, String filepath) {
         cancelled = false;
         progbar.setProgress(0);
         // don't show proglayout immediately
         // proglayout.setVisibility(LinearLayout.VISIBLE);
-        
-        dresult = "";
+
+        // we cannot do network connections on main thread
+        final Handler handler = new Handler();
         final String durl = urlstring;
         final String dfile = filepath;
         Thread download_thread = new Thread(new Runnable() {
+            @Override
             public void run() {
                 dresult = downloadURL(durl, dfile);
-                handler.sendMessage(handler.obtainMessage());
+                handler.post(new Runnable() {
+                    @Override
+                    public void run() {
+                        proglayout.setVisibility(LinearLayout.INVISIBLE);
+                        if (dresult.length() == 0) {
+                            // download succeeded
+                            nativeProcessDownload(dfile);
+                        } else if (!cancelled) {
+                            Toast.makeText(HelpActivity.this, "Download failed! " + dresult, Toast.LENGTH_SHORT).show();
+                        }
+                    }
+                });
             }
         });
         
         download_thread.setPriority(Thread.MAX_PRIORITY);
         download_thread.start();
-        
-        // wait for thread to finish
-        try { Looper.loop(); } catch(RuntimeException re) {}
-        
-        proglayout.setVisibility(LinearLayout.INVISIBLE);
-        
-        if (dresult.length() > 0 && !cancelled) {
-            Toast.makeText(this, "Download failed! " + dresult, Toast.LENGTH_SHORT).show();
-        }
-        return dresult;
     }
 
 } // HelpActivity class
