@@ -1,31 +1,11 @@
-/*** /
-
- This file is part of Golly, a Game of Life Simulator.
- Copyright (C) 2013 Andrew Trevorrow and Tomas Rokicki.
-
- This program is free software; you can redistribute it and/or
- modify it under the terms of the GNU General Public License
- as published by the Free Software Foundation; either version 2
- of the License, or (at your option) any later version.
-
- This program is distributed in the hope that it will be useful,
- but WITHOUT ANY WARRANTY; without even the implied warranty of
- MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- GNU General Public License for more details.
-
- You should have received a copy of the GNU General Public License
- along with this program; if not, write to the Free Software
- Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
-
- Web site:  http://sourceforge.net/projects/golly
- Authors:   rokicki@gmail.com  andrew@trevorrow.com
-
- / ***/
+// This file is part of Golly.
+// See docs/License.html for the copyright notice.
 
 package net.sf.golly;
 
 import java.io.File;
 
+import android.app.Activity;
 import android.app.AlertDialog;
 import android.content.ClipData;
 import android.content.ClipboardManager;
@@ -55,7 +35,7 @@ import android.widget.ProgressBar;
 import android.widget.RelativeLayout;
 import android.widget.TextView;
 
-public class MainActivity extends BaseActivity {
+public class MainActivity extends Activity {
 
     // see jnicalls.cpp for these native routines:
     private static native void nativeClassInit();   // this MUST be static
@@ -185,7 +165,7 @@ public class MainActivity extends BaseActivity {
         public void run() {
             Looper looper = Looper.myLooper();
             looper.quit();
-            evthandler.removeCallbacks(this);    
+            evthandler.removeCallbacks(this);
             evthandler = null;
         }
     };
@@ -206,10 +186,11 @@ public class MainActivity extends BaseActivity {
     private void CheckMessageQueue() {
         // process any pending UI events in message queue
         if (!processingevents) {
-            Looper.myQueue().addIdleHandler(new IdleHandler(Looper.myLooper()));
+            Looper looper = Looper.myLooper();
+            looper.myQueue().addIdleHandler(new IdleHandler(looper));
             processingevents = true;
             try {
-                Looper.loop();
+                looper.loop();
             } catch (RuntimeException re) {
                 // looper.quit() in doevents causes an exception
             }
@@ -284,7 +265,7 @@ public class MainActivity extends BaseActivity {
         
         restorebutton.setVisibility(View.INVISIBLE);
         proglayout.setVisibility(LinearLayout.INVISIBLE);
-        
+
         // create handler and runnable for generating patterns
         geninterval = nativeCalculateSpeed();
         genhandler = new Handler();
@@ -1034,6 +1015,7 @@ public class MainActivity extends BaseActivity {
                         PlayBeepSound();
                         return;
                     }
+                    BaseApp baseapp = (BaseApp)getApplicationContext();
                     // check for valid extension
                     if (!nativeValidExtension(filename)) {
                         baseapp.Warning("Invalid file extension.");
@@ -1251,6 +1233,7 @@ public class MainActivity extends BaseActivity {
 
     // this method is called from C++ code (see jnicalls.cpp)
     private String GetTextFromClipboard() {
+        BaseApp baseapp = (BaseApp)getApplicationContext();
         ClipboardManager clipboard = (ClipboardManager) getSystemService(Context.CLIPBOARD_SERVICE);
         String text = "";
         if (clipboard.hasPrimaryClip()) {
@@ -1268,6 +1251,7 @@ public class MainActivity extends BaseActivity {
 
     // this method is called from C++ code (see jnicalls.cpp)
     private void ShowTextFile(String filepath) {
+        BaseApp baseapp = (BaseApp)getApplicationContext();
         // display file contents
         Intent intent = new Intent(baseapp.getCurrentActivity(), InfoActivity.class);
         intent.putExtra(InfoActivity.INFO_MESSAGE, filepath);
@@ -1302,7 +1286,10 @@ public class MainActivity extends BaseActivity {
 
     // this method is called from C++ code (see jnicalls.cpp)
     private boolean AbortProgress(int percentage, String message) {
-        if (progresscount <= 0) baseapp.Fatal("Bug detected in AbortProgress!");
+        if (progresscount <= 0) {
+            Log.e("Golly","Bug detected in AbortProgress!");
+            return true;
+        }
         long nanosecs = System.nanoTime() - progstart;
         if (proglayout.getVisibility() == LinearLayout.VISIBLE) {
             if (nanosecs < prognext) return false;
@@ -1334,7 +1321,10 @@ public class MainActivity extends BaseActivity {
 
     // this method is called from C++ code (see jnicalls.cpp)
     private void EndProgress() {
-        if (progresscount <= 0) baseapp.Fatal("Bug detected in EndProgress!");
+        if (progresscount <= 0) {
+            Log.e("Golly","Bug detected in EndProgress!");
+            return;
+        }
         progresscount--;
         if (progresscount == 0) {
             proglayout.setVisibility(LinearLayout.INVISIBLE);
