@@ -1,32 +1,12 @@
-/*** /
-
- This file is part of Golly, a Game of Life Simulator.
- Copyright (C) 2013 Andrew Trevorrow and Tomas Rokicki.
-
- This program is free software; you can redistribute it and/or
- modify it under the terms of the GNU General Public License
- as published by the Free Software Foundation; either version 2
- of the License, or (at your option) any later version.
-
- This program is distributed in the hope that it will be useful,
- but WITHOUT ANY WARRANTY; without even the implied warranty of
- MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- GNU General Public License for more details.
-
- You should have received a copy of the GNU General Public License
- along with this program; if not, write to the Free Software
- Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
-
- Web site:  http://sourceforge.net/projects/golly
- Authors:   rokicki@gmail.com  andrew@trevorrow.com
-
- / ***/
+// This file is part of Golly.
+// See docs/License.html for the copyright notice.
 
 package net.sf.golly;
 
 import java.io.File;
 import java.util.Arrays;
 
+import android.app.Activity;
 import android.app.AlertDialog;
 import android.content.DialogInterface;
 import android.content.Intent;
@@ -48,7 +28,7 @@ import android.widget.TextView;
 import android.widget.TextView.OnEditorActionListener;
 import android.widget.Toast;
 
-public class RuleActivity extends BaseActivity {
+public class RuleActivity extends Activity {
 
     // see jnicalls.cpp for these native routines:
     private native void nativeSaveCurrentSelection();
@@ -145,6 +125,7 @@ public class RuleActivity extends BaseActivity {
     // -----------------------------------------------------------------------------
     
     private void removeFile(String filepath) {
+        BaseApp baseapp = (BaseApp)getApplicationContext();
         final String fullpath = baseapp.userdir.getAbsolutePath() + "/" + filepath;
         final File file = new File(fullpath);
         
@@ -172,6 +153,7 @@ public class RuleActivity extends BaseActivity {
     // -----------------------------------------------------------------------------
     
     private void editFile(String filepath) {
+        BaseApp baseapp = (BaseApp)getApplicationContext();
         // let user read/edit given file
         if (filepath.startsWith("Supplied/")) {
             // read contents of supplied .rule file into a string
@@ -328,6 +310,7 @@ public class RuleActivity extends BaseActivity {
     // -----------------------------------------------------------------------------
     
     private void showAlgoHelp() {
+        BaseApp baseapp = (BaseApp)getApplicationContext();
         String algoname = nativeGetAlgoName(algoindex);
         if (algoname.equals("RuleLoader")) {
             // create html data with links to the user's .rule files and the supplied .rule files
@@ -348,6 +331,8 @@ public class RuleActivity extends BaseActivity {
             htmldata += "</b></font></body></html>";
             gwebview.loadDataWithBaseURL(null, htmldata, "text/html", "utf-8", null);
         } else {
+            // replace any spaces with underscores
+            algoname = algoname.replaceAll(" ", "_");
             // display html data in supplieddir/Help/Algorithms/algoname.html
             String fullpath = baseapp.supplieddir.getAbsolutePath() + "/Help/Algorithms/" + algoname + ".html";
             File htmlfile = new File(fullpath);
