@@ -139,10 +139,32 @@ void SetGenIncrement()
 {
     if (currlayer->currexpo > 0) {
         bigint inc = 1;
+        int maxexpo = 1 ;
+        if (currlayer->currbase <= 10000) {
+           int mantissa = currlayer->currbase ;
+           int himantissa = 0x7fffffff ;
+           while (mantissa > 1 && 0 == (mantissa & 1))
+              mantissa >>= 1 ;
+           if (mantissa == 1) {
+              maxexpo = 0x7fffffff ;
+           } else {
+              int p = mantissa ;
+              while (p <= himantissa / mantissa) {
+                 p *= mantissa ;
+                 maxexpo++ ;
+              }
+           }
+        }
+        if (currlayer->currexpo > maxexpo)
+           currlayer->currexpo = maxexpo ;
         // set increment to currbase^currexpo
         int i = currlayer->currexpo;
         while (i > 0) {
-            inc.mul_smallint(currlayer->currbase);
+            if (currlayer->currbase > 10000) {
+               inc = currlayer->currbase ;
+            } else {
+               inc.mul_smallint(currlayer->currbase);
+            }
             i--;
         }
         currlayer->algo->setIncrement(inc);
@@ -780,7 +802,7 @@ void ChangeRule(const std::string& rulestring)
             ClearOutsideGrid();
         }
 
-		// new table/tree might have changed the number of cell states;
+		// new rule might have changed the number of cell states;
 		// if there are fewer states then pattern might change
 		if (newmaxstate < oldmaxstate && !currlayer->algo->isEmpty()) {
 			ReduceCellStates(newmaxstate);
