@@ -1,26 +1,5 @@
-/*** /
-
- This file is part of Golly, a Game of Life Simulator.
- Copyright (C) 2013 Andrew Trevorrow and Tomas Rokicki.
-
- This program is free software; you can redistribute it and/or
- modify it under the terms of the GNU General Public License
- as published by the Free Software Foundation; either version 2
- of the License, or (at your option) any later version.
-
- This program is distributed in the hope that it will be useful,
- but WITHOUT ANY WARRANTY; without even the implied warranty of
- MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- GNU General Public License for more details.
-
- You should have received a copy of the GNU General Public License
- along with this program; if not, write to the Free Software
- Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
-
- Web site:  http://sourceforge.net/projects/golly
- Authors:   rokicki@gmail.com  andrew@trevorrow.com
-
- / ***/
+// This file is part of Golly.
+// See docs/License.html for the copyright notice.
 
 #ifdef ANDROID_GUI
     #include "jnicalls.h"   // for SwitchToPatternTab, ShowTextFile, ShowHelp, etc
@@ -44,6 +23,7 @@
 #include <list>             // for std::list
 #include <stdexcept>        // for std::runtime_error and std::exception
 #include <sstream>          // for std::ostringstream
+#include <algorithm>        // for std::replace
 
 #include "bigint.h"
 #include "lifealgo.h"
@@ -485,7 +465,7 @@ bool ExtractZipEntry(const std::string& zippath, const std::string& entryname, c
                     oss << "Error opening current zip entry:\n" << entryname.c_str();
                     throw std::runtime_error(oss.str().c_str());
                 }
-                int bytesRead = unzReadCurrentFile(zfile, zipdata, file_info.uncompressed_size);
+                int bytesRead = unzReadCurrentFile(zfile, zipdata, (unsigned int)file_info.uncompressed_size);
                 if (bytesRead < 0) {
                     throw std::runtime_error("Error reading the zip entry data!");
                 }
@@ -605,7 +585,7 @@ static bool RuleInstalled(unzFile zfile, unz_file_info& info, const std::string&
         return false;
     }
     
-    int bytesRead = unzReadCurrentFile(zfile, zipdata, info.uncompressed_size);
+    int bytesRead = unzReadCurrentFile(zfile, zipdata, (unsigned int)info.uncompressed_size);
     if (bytesRead < 0) {
         // error is detected below
     }
@@ -707,7 +687,7 @@ void OpenZipFile(const char* zippath)
                 // indent depending on # of separators in name
                 unsigned int sepcount = 0;
                 unsigned int i = 0;
-                unsigned int len = name.length();
+                unsigned int len = (unsigned int)name.length();
                 while (i < len) {
                     if (name[i] == '/') sepcount++;
                     i++;
@@ -1027,36 +1007,6 @@ bool SavePattern(const std::string& path, pattern_format format, output_compress
 
 // -----------------------------------------------------------------------------
 
-bool DownloadFile(const std::string& url, const std::string& filepath)
-{
-#ifdef ANDROID_GUI
-    return AndroidDownloadFile(url, filepath);
-#endif
-
-#ifdef WEB_GUI
-    return WebDownloadFile(url, filepath);
-#endif
-
-#ifdef IOS_GUI
-    NSURL *nsurl = [NSURL URLWithString:[NSString stringWithCString:url.c_str() encoding:NSUTF8StringEncoding]];
-    if (nsurl == nil) {
-        std::string msg = "Bad URL: " + url;
-        Warning(msg.c_str());
-        return false;
-    }
-    NSData *urlData = [NSData dataWithContentsOfURL:nsurl];
-    if (urlData) {
-        [urlData writeToFile:[NSString stringWithCString:filepath.c_str() encoding:NSUTF8StringEncoding] atomically:YES];
-        return true;
-    } else {
-        Warning("Failed to download file!");
-        return false;
-    }
-#endif
-}
-
-// -----------------------------------------------------------------------------
-
 void GetURL(const std::string& url, const std::string& pageurl)
 {
     const char* HTML_PREFIX = "GET-";   // prepended to html filename
@@ -1122,8 +1072,51 @@ void GetURL(const std::string& url, const std::string& pageurl)
     }
 
     // download the file and store it in filepath
-    if (!DownloadFile(fullurl, filepath)) return;
+    if (DownloadFile(fullurl, filepath)) {
+        ProcessDownload(filepath);
+    }
+}
 
+// -----------------------------------------------------------------------------
+
+bool DownloadFile(const std::string& url, const std::string& filepath)
+{
+#ifdef ANDROID_GUI
+    AndroidDownloadFile(url, filepath);
+    // on Android the file is downloaded asynchronously, so we need to return false
+    // here so that GetURL won't call ProcessDownload immediately (it will be called
+    // later if the download succeeds)
+    return false;
+#endif
+
+#ifdef WEB_GUI
+    return WebDownloadFile(url, filepath);
+#endif
+
+#ifdef IOS_GUI
+    NSURL *nsurl = [NSURL URLWithString:[NSString stringWithCString:url.c_str() encoding:NSUTF8StringEncoding]];
+    if (nsurl == nil) {
+        std::string msg = "Bad URL: " + url;
+        Warning(msg.c_str());
+        return false;
+    }
+    NSData *urlData = [NSData dataWithContentsOfURL:nsurl];
+    if (urlData) {
+        [urlData writeToFile:[NSString stringWithCString:filepath.c_str() encoding:NSUTF8StringEncoding] atomically:YES];
+        return true;
+    } else {
+        Warning("Failed to download file!");
+        return false;
+    }
+#endif
+}
+
+// -----------------------------------------------------------------------------
+
+void ProcessDownload(const std::string& filepath)
+{
+    // process a successfully downloaded file
+    std::string filename = GetBaseName(filepath.c_str());
     if (IsHTMLFile(filename)) {
         // display html file in Help tab
         ShowHelp(filepath.c_str());
