@@ -1,26 +1,5 @@
-/*** /
-
- This file is part of Golly, a Game of Life Simulator.
- Copyright (C) 2013 Andrew Trevorrow and Tomas Rokicki.
-
- This program is free software; you can redistribute it and/or
- modify it under the terms of the GNU General Public License
- as published by the Free Software Foundation; either version 2
- of the License, or (at your option) any later version.
-
- This program is distributed in the hope that it will be useful,
- but WITHOUT ANY WARRANTY; without even the implied warranty of
- MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- GNU General Public License for more details.
-
- You should have received a copy of the GNU General Public License
- along with this program; if not, write to the Free Software
- Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
-
- Web site:  http://sourceforge.net/projects/golly
- Authors:   rokicki@gmail.com  andrew@trevorrow.com
-
- / ***/
+// This file is part of Golly.
+// See docs/License.html for the copyright notice.
 
 #include "lifealgo.h"
 #include "viewport.h"       // for MAX_MAG
@@ -87,7 +66,7 @@ bool swapcolors = false;            // swap colors used for cell states?
 bool allowundo = true;              // allow undo/redo?
 bool allowbeep = true;              // okay to play beep sound?
 bool restoreview = true;            // should reset/undo restore view?
-int canchangerule = 1;              // if > 0 then paste can change rule (1 means change rule only if pattern is empty)
+int canchangerule = 1;              // if > 0 then paste can change rule if pattern is empty
 int randomfill = 50;                // random fill percentage (1..100)
 int opacity = 80;                   // percentage opacity of live cells in overlays (1..100)
 int tileborder = 3;                 // thickness of tiled window borders
