@@ -1,26 +1,5 @@
-/*** /
-
- This file is part of Golly, a Game of Life Simulator.
- Copyright (C) 2013 Andrew Trevorrow and Tomas Rokicki.
-
- This program is free software; you can redistribute it and/or
- modify it under the terms of the GNU General Public License
- as published by the Free Software Foundation; either version 2
- of the License, or (at your option) any later version.
-
- This program is distributed in the hope that it will be useful,
- but WITHOUT ANY WARRANTY; without even the implied warranty of
- MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- GNU General Public License for more details.
-
- You should have received a copy of the GNU General Public License
- along with this program; if not, write to the Free Software
- Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
-
- Web site:  http://sourceforge.net/projects/golly
- Authors:   rokicki@gmail.com  andrew@trevorrow.com
-
- / ***/
+// This file is part of Golly.
+// See docs/License.html for the copyright notice.
 
 #include "bigint.h"
 #include "lifealgo.h"
@@ -36,6 +15,7 @@
 #include "control.h"        // for generating, etc
 #include "file.h"           // for CreateUniverse
 #include "select.h"
+#include <stdlib.h>         // for rand
 
 #ifdef ANDROID_GUI
     #include "jnicalls.h"   // for BeginProgress, etc
@@ -291,7 +271,7 @@ void Selection::Advance()
     bool savecells = allowundo && !currlayer->stayclean;
     //!!! if (savecells && inscript) SavePendingChanges();
 
-    bool boundedgrid = (currlayer->algo->gridwd > 0 || currlayer->algo->gridht > 0);
+    bool boundedgrid = currlayer->algo->unbounded && (currlayer->algo->gridwd > 0 || currlayer->algo->gridht > 0);
 
     // check if selection encloses entire pattern;
     // can't do this if qlife because it uses gen parity to decide which bits to draw;
@@ -429,7 +409,7 @@ void Selection::AdvanceOutside()
     bool savecells = allowundo && !currlayer->stayclean;
     //!!! if (savecells && inscript) SavePendingChanges();
 
-    bool boundedgrid = (currlayer->algo->gridwd > 0 || currlayer->algo->gridht > 0);
+    bool boundedgrid = currlayer->algo->unbounded && (currlayer->algo->gridwd > 0 || currlayer->algo->gridht > 0);
 
     // check if selection is completely outside pattern edges;
     // can't do this if qlife because it uses gen parity to decide which bits to draw;
@@ -1176,7 +1156,7 @@ void Selection::AddRun(int state,                // in: state of cell to write
 
     if ( run > 1 ) {
         sprintf(numstr, "%u", run);
-        numlen = strlen(numstr);
+        numlen = (unsigned int)strlen(numstr);
     } else {
         numlen = 0;                      // no run count shown if 1
     }
@@ -1246,7 +1226,7 @@ void Selection::CopyToClipboard(bool cut)
     chptr += strlen(textptr);
     AddEOL(chptr);
     // save start of data in case livecount is zero
-    int datastart = chptr - textptr;
+    int datastart = int(chptr - textptr);
 
     // add RLE pattern data
     unsigned int livecount = 0;
@@ -1441,7 +1421,7 @@ void Selection::RandomFill()
     BeginProgress("Randomly filling selection");
     int cx, cy;
     lifealgo* curralgo = currlayer->algo;
-    int livestates = curralgo->NumCellStates() - 1;    // don't count dead state
+    int livestates = curralgo->NumRandomizedCellStates() - 1;    // don't count dead state
 
     for ( cy=itop; cy<=ibottom; cy++ ) {
         for ( cx=ileft; cx<=iright; cx++ ) {
