@@ -1,26 +1,5 @@
-/*** /
-
- This file is part of Golly, a Game of Life Simulator.
- Copyright (C) 2013 Andrew Trevorrow and Tomas Rokicki.
-
- This program is free software; you can redistribute it and/or
- modify it under the terms of the GNU General Public License
- as published by the Free Software Foundation; either version 2
- of the License, or (at your option) any later version.
-
- This program is distributed in the hope that it will be useful,
- but WITHOUT ANY WARRANTY; without even the implied warranty of
- MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- GNU General Public License for more details.
-
- You should have received a copy of the GNU General Public License
- along with this program; if not, write to the Free Software
- Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
-
- Web site:  http://sourceforge.net/projects/golly
- Authors:   rokicki@gmail.com  andrew@trevorrow.com
-
- / ***/
+// This file is part of Golly.
+// See docs/License.html for the copyright notice.
 
 #include <sys/time.h>   // for gettimeofday
 #include <algorithm>    // for std::transform
@@ -464,7 +443,8 @@ bool IsScriptFile(const std::string& filename)
     if (dotpos == std::string::npos) return false;
 
     std::string ext = filename.substr(dotpos+1);
-    return ( strcasecmp(ext.c_str(),"pl") == 0 ||
+    return ( strcasecmp(ext.c_str(),"lua") == 0 ||
+             strcasecmp(ext.c_str(),"pl") == 0 ||
              strcasecmp(ext.c_str(),"py") == 0 );
 }
 
