@@ -1,26 +1,5 @@
-/*** /
-
- This file is part of Golly, a Game of Life Simulator.
- Copyright (C) 2013 Andrew Trevorrow and Tomas Rokicki.
-
- This program is free software; you can redistribute it and/or
- modify it under the terms of the GNU General Public License
- as published by the Free Software Foundation; either version 2
- of the License, or (at your option) any later version.
-
- This program is distributed in the hope that it will be useful,
- but WITHOUT ANY WARRANTY; without even the implied warranty of
- MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- GNU General Public License for more details.
-
- You should have received a copy of the GNU General Public License
- along with this program; if not, write to the Free Software
- Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
-
- Web site:  http://sourceforge.net/projects/golly
- Authors:   rokicki@gmail.com  andrew@trevorrow.com
-
- / ***/
+// This file is part of Golly.
+// See docs/License.html for the copyright notice.
 
 #include "bigint.h"
 #include "lifealgo.h"
@@ -39,6 +18,7 @@
 #include "control.h"        // for generating, ChangeRule
 #include "file.h"           // for GetTextFromClipboard
 #include "view.h"
+#include <cstdlib>          // for abs
 
 #ifdef ANDROID_GUI
     #include "jnicalls.h"   // for UpdatePattern, BeginProgress, etc
@@ -967,26 +947,17 @@ bool GetClipboardPattern(Layer* templayer, bigint* t, bigint* l, bigint* b, bigi
         }
     }
 
-    if (!err && canchangerule > 0) {
-        // set newrule for later use in PasteTemporaryToCurrent
-        if (canchangerule == 1 && !currlayer->algo->isEmpty()) {
-            // don't change rule if universe isn't empty
-            newrule = oldrule;
-        } else {
-            // remember rule set by readclipboard
-            newrule = templayer->algo->getrule();
-        }
-    }
-
     RemoveFile(clipfile);
 
     if (err) {
         // error probably due to bad rule string in clipboard data
         Warning("Could not load clipboard pattern\n(probably due to unknown rule).");
         return false;
+    } else {
+        // set newrule for later use in PasteTemporaryToCurrent
+        newrule = templayer->algo->getrule();
+        return true;
     }
-
-    return true;
 }
 
 // -----------------------------------------------------------------------------
@@ -1143,7 +1114,7 @@ void PasteTemporaryToCurrent(bigint top, bigint left, bigint wd, bigint ht)
 
     // pasting clipboard pattern can cause a rule change
     int oldmaxstate = currlayer->algo->NumCellStates() - 1;
-    if (canchangerule > 0 && oldrule != newrule) {
+    if (canchangerule > 0 && currlayer->algo->isEmpty() && oldrule != newrule) {
         const char* err = currlayer->algo->setrule( newrule.c_str() );
         // setrule can fail if readclipboard loaded clipboard pattern into
         // a different type of algo
@@ -1437,8 +1408,50 @@ bool FlipPastePattern(bool topbottom)
 
 bool RotatePastePattern(bool clockwise)
 {
-    bool result;
-    Selection pastesel(pastebox.y, pastebox.x, pastebox.y + pastebox.height - 1, pastebox.x + pastebox.width - 1);
+    Selection pastesel(pastebox.y, pastebox.x,
+                       pastebox.y + pastebox.height - 1,
+                       pastebox.x + pastebox.width - 1);
+    
+    // check if pastelayer->algo uses a finite grid
+    if (!pastelayer->algo->unbounded) {
+        // readclipboard has loaded the pattern into top left corner of grid,
+        // so if pastebox isn't square we need to expand the grid to avoid the
+        // rotated pattern being clipped (WARNING: this assumes the algo won't
+        // change the pattern's cell coordinates when setrule expands the grid)
+        int x, y, wd, ht;
+        pastesel.GetRect(&x, &y, &wd, &ht);
+        if (wd != ht) {
+        
+            // better solution would be to check if pastebox is small enough for
+            // pattern to be safely rotated after shifting to center of grid and only
+            // expand grid if it can't!!!??? (must also update pastesel edges)
+            
+            int newwd, newht;
+            if (wd > ht) {
+                // expand grid vertically
+                newht = pastelayer->algo->gridht + wd;
+                newwd = pastelayer->algo->gridwd;
+            } else {
+                // wd < ht so expand grid horizontally
+                newwd = pastelayer->algo->gridwd + ht;
+                newht = pastelayer->algo->gridht;
+            }
+            char rule[MAXRULESIZE];
+            sprintf(rule, "%s", pastelayer->algo->getrule());
+            char topology = 'T';
+            char *suffix = strchr(rule, ':');
+            if (suffix) {
+                topology = suffix[1];
+                suffix[0] = 0;
+            }
+            sprintf(rule, "%s:%c%d,%d", rule, topology, newwd, newht);
+            if (pastelayer->algo->setrule(rule)) {
+                // unlikely, but could happen if the new grid size is too big
+                Warning("Sorry, but the clipboard pattern could not be rotated.");
+                return false;
+            }
+        }
+    }
 
     // rotate the pattern in pastelayer
     lifealgo* savealgo = currlayer->algo;
@@ -1449,7 +1462,7 @@ bool RotatePastePattern(bool clockwise)
     // and layer won't be marked as dirty; also set inscript temporarily
     // so that viewport won't be updated and selection size won't be displayed
     inscript = true;
-    result = pastesel.Rotate(clockwise, true);
+    bool result = pastesel.Rotate(clockwise, true);
     // currlayer->algo might point to a *different* universe
     pastelayer->algo = currlayer->algo;
     currlayer->algo = savealgo;
