@@ -1,26 +1,5 @@
-/*** /
- 
- This file is part of Golly, a Game of Life Simulator.
- Copyright (C) 2013 Andrew Trevorrow and Tomas Rokicki.
- 
- This program is free software; you can redistribute it and/or
- modify it under the terms of the GNU General Public License
- as published by the Free Software Foundation; either version 2
- of the License, or (at your option) any later version.
- 
- This program is distributed in the hope that it will be useful,
- but WITHOUT ANY WARRANTY; without even the implied warranty of
- MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- GNU General Public License for more details.
- 
- You should have received a copy of the GNU General Public License
- along with this program; if not, write to the Free Software
- Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
- 
- Web site:  http://sourceforge.net/projects/golly
- Authors:   rokicki@gmail.com  andrew@trevorrow.com
- 
- / ***/
+// This file is part of Golly.
+// See docs/License.html for the copyright notice.
 
 #include <string>       // for std::string
 #include <list>         // for std::list
@@ -105,7 +84,7 @@ static void AppendHtmlData(std::string& htmldata, const std::string& dir,
         std::string pstr = [path cStringUsingEncoding:NSUTF8StringEncoding];
 
         // indent level is number of separators in path
-        int indents = std::count(pstr.begin(), pstr.end(), '/');
+        int indents = (int)std::count(pstr.begin(), pstr.end(), '/');
         
         if (indents <= closedlevel) {
             NSString *fullpath = [pattdir stringByAppendingPathComponent:path];
@@ -342,7 +321,7 @@ static void AppendHtmlData(std::string& htmldata, const std::string& dir,
     curroffset[curroption] = htmlView.scrollView.contentOffset;
     
     // display selected set of files
-    curroption = [indexPath row];
+    curroption = (int)[indexPath row];
     switch (curroption) {
         case 0: [self showSuppliedPatterns]; break;
         case 1: [self showRecentPatterns]; break;
