@@ -1,26 +1,5 @@
-/*** /
- 
- This file is part of Golly, a Game of Life Simulator.
- Copyright (C) 2013 Andrew Trevorrow and Tomas Rokicki.
- 
- This program is free software; you can redistribute it and/or
- modify it under the terms of the GNU General Public License
- as published by the Free Software Foundation; either version 2
- of the License, or (at your option) any later version.
- 
- This program is distributed in the hope that it will be useful,
- but WITHOUT ANY WARRANTY; without even the implied warranty of
- MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- GNU General Public License for more details.
- 
- You should have received a copy of the GNU General Public License
- along with this program; if not, write to the Free Software
- Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
- 
- Web site:  http://sourceforge.net/projects/golly
- Authors:   rokicki@gmail.com  andrew@trevorrow.com
- 
- / ***/
+// This file is part of Golly.
+// See docs/License.html for the copyright notice.
 
 #include "utils.h"      // for Beep
 #include "status.h"     // for ClearMessage
@@ -273,7 +252,7 @@ static int oldhashmem;      // detect if user changed maxhashmem
     // called when editing has ended (ie. keyboard disappears)
     if (tf == percentageText) {
         if (tf.text.length > 0) {
-            randomfill = [tf.text integerValue];
+            randomfill = (int)[tf.text integerValue];
             if (randomfill < 1) randomfill = 1;
             if (randomfill > 100) randomfill = 100;
         }
@@ -281,7 +260,7 @@ static int oldhashmem;      // detect if user changed maxhashmem
         percentageSlider.value = randomfill;
     } else if (tf == memoryText) {
         if (tf.text.length > 0) {
-            maxhashmem = [tf.text integerValue];
+            maxhashmem = (int)[tf.text integerValue];
             if (maxhashmem < MIN_MEM_MB) maxhashmem = MIN_MEM_MB;
             if (maxhashmem > MAX_MEM_MB) maxhashmem = MAX_MEM_MB;
         }
