@@ -389,10 +389,32 @@ void MainFrame::SetGenIncrement()
 {
     if (currlayer->currexpo > 0) {
         bigint inc = 1;
+        int maxexpo = 1 ;
+        if (currlayer->currbase <= 10000) {
+           int mantissa = currlayer->currbase ;
+           int himantissa = 0x7fffffff ;
+           while (mantissa > 1 && 0 == (mantissa & 1))
+              mantissa >>= 1 ;
+           if (mantissa == 1) {
+              maxexpo = 0x7fffffff ;
+           } else {
+              int p = mantissa ;
+              while (p <= himantissa / mantissa) {
+                 p *= mantissa ;
+                 maxexpo++ ;
+              }
+           }
+        }
+        if (currlayer->currexpo > maxexpo)
+           currlayer->currexpo = maxexpo ;
         // set increment to currbase^currexpo
         int i = currlayer->currexpo;
         while (i > 0) {
-            inc.mul_smallint(currlayer->currbase);
+            if (currlayer->currbase > 10000) {
+               inc = currlayer->currbase ;
+            } else {
+               inc.mul_smallint(currlayer->currbase);
+            }
             i--;
         }
         currlayer->algo->setIncrement(inc);
@@ -523,6 +545,8 @@ void MainFrame::DisplayPattern()
     // exist it only updates the current tile if possible; ie. it's not a clone
     // and tile views aren't synchronized
     
+    if (IsIconized()) return;
+    
     if (tilelayers && numlayers > 1 && !syncviews && currlayer->cloneid == 0) {
         // only update the current tile
         viewptr->Refresh(false);
@@ -717,7 +741,9 @@ void MainFrame::DoPendingAction(bool restart)
         
         UpdateEverything();
         
-        // do the drawing
+        // do the drawing by creating a mouse down event so PatternView::OnMouseDown is called again,
+        // but we need to reset mouseisdown flag which is currently true
+        viewptr->mouseisdown = false;
         mouseevent.SetEventType(wxEVT_LEFT_DOWN);
         mouseevent.SetEventObject(viewptr);
         viewptr->GetEventHandler()->ProcessEvent(mouseevent);
@@ -1131,7 +1157,7 @@ void MainFrame::ToggleShowPopulation()
 {
     showpopulation = !showpopulation;
     
-    if (generating && showstatus) statusptr->Refresh(false);
+    if (generating && showstatus && !IsIconized()) statusptr->Refresh(false);
 }
 
 // -----------------------------------------------------------------------------
