@@ -1,26 +1,5 @@
-/*** /
- 
- This file is part of Golly, a Game of Life Simulator.
- Copyright (C) 2013 Andrew Trevorrow and Tomas Rokicki.
- 
- This program is free software; you can redistribute it and/or
- modify it under the terms of the GNU General Public License
- as published by the Free Software Foundation; either version 2
- of the License, or (at your option) any later version.
- 
- This program is distributed in the hope that it will be useful,
- but WITHOUT ANY WARRANTY; without even the implied warranty of
- MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- GNU General Public License for more details.
- 
- You should have received a copy of the GNU General Public License
- along with this program; if not, write to the Free Software
- Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
- 
- Web site:  http://sourceforge.net/projects/golly
- Authors:   rokicki@gmail.com  andrew@trevorrow.com
- 
- / ***/
+// This file is part of Golly.
+// See docs/License.html for the copyright notice.
 
 #ifndef _WXPREFS_H_
 #define _WXPREFS_H_
@@ -83,6 +62,7 @@ extern char initrule[];          // initial rule
 extern bool initautofit;         // initial autofit setting
 extern bool inithyperspeed;      // initial hyperspeed setting
 extern bool initshowhashinfo;    // initial showhashinfo setting
+extern bool showpopulation;      // show population counts while generating?
 extern bool savexrle;            // save RLE file using XRLE format?
 extern bool showtips;            // show button tips?
 extern bool showtool;            // show tool bar?
@@ -91,8 +71,10 @@ extern bool showedit;            // show edit bar?
 extern bool showallstates;       // show all cell states in edit bar?
 extern bool showstatus;          // show status bar?
 extern bool showexact;           // show exact numbers in status bar?
+extern bool showscrollbars;      // show scroll bars?
 extern bool showtimeline;        // show timeline bar?
 extern bool showgridlines;       // display grid lines?
+extern bool showoverlay;         // display the current overlay?
 extern bool showicons;           // display icons for cell states?
 extern bool smartscale;          // smarter scaling when zoomed out?
 extern bool swapcolors;          // swap colors used for cell states?
@@ -111,6 +93,7 @@ extern int mingridmag;           // minimum mag to draw grid lines
 extern int boldspacing;          // spacing of bold grid lines
 extern bool showboldlines;       // show bold grid lines?
 extern bool mathcoords;          // show Y values increasing upwards?
+extern bool cellborders;         // should zoomed cells have borders?
 extern bool syncviews;           // synchronize viewports?
 extern bool synccursors;         // synchronize cursors?
 extern bool stacklayers;         // stack all layers?
@@ -127,9 +110,11 @@ extern wxCursor* newcurs;        // cursor after creating new pattern
 extern wxCursor* opencurs;       // cursor after opening pattern
 extern int mousewheelmode;       // 0:Ignore, 1:forward=ZoomOut, 2:forward=ZoomIn
 extern int thumbrange;           // thumb box scrolling range in terms of view wd/ht
+extern int wheelsens;            // mouse wheel sensitivity
 extern int mindelay;             // minimum millisec delay
 extern int maxdelay;             // maximum millisec delay
-extern wxString opensavedir;     // directory for Open and Save dialogs
+extern wxString opensavedir;     // directory for Open/Save Pattern dialogs
+extern wxString overlaydir;      // directory for Save Overlay dialog
 extern wxString rundir;          // directory for Run Script dialog
 extern wxString choosedir;       // directory used by Choose File button
 extern wxString filedir;         // directory used by Show Files
@@ -178,6 +163,7 @@ typedef enum {
     DO_PASTEMODE,                 // cycle paste mode
     DO_DELETE,                    // delete layer
     DO_DELOTHERS,                 // delete other layers
+    DO_DELOVERLAY,                // delete overlay
     DO_DELTIME,                   // delete timeline
     DO_DISABLE,                   // disable undo/redo
     DO_DUPLICATE,                 // duplicate layer
@@ -215,6 +201,7 @@ typedef enum {
     DO_RUNCLIP,                   // run clipboard
     DO_RUNSCRIPT,                 // run script...
     DO_SAVEXRLE,                  // save extended rle
+    DO_SAVEOVERLAY,               // save overlay...
     DO_SAVE,                      // save pattern...
     DO_DOWN,                      // scroll down
     DO_LEFT,                      // scroll left
@@ -245,6 +232,9 @@ typedef enum {
     DO_HASHINFO,                  // show hash info
     DO_HELP,                      // show help
     DO_SHOWLAYER,                 // show layer bar
+    DO_SHOWOVERLAY,               // show overlay
+    DO_SHOWPOP,                   // show population
+    DO_SHOWSCROLL,                // show scroll bars
     DO_SHOWSTATUS,                // show status bar
     DO_SHOWTIME,                  // show timeline
     DO_TIMING,                    // show timing
@@ -318,6 +308,7 @@ const int MAX_MEM_MB =           // maximum value of maximum memory
 const int MAX_BASESTEP = 2000000000;    // maximum base step
 const int MAX_DELAY = 5000;      // maximum mindelay or maxdelay
 const int MAX_THUMBRANGE = 500;  // maximum thumbrange
+const int MAX_SENSITIVITY = 10;  // maximum wheelsens
 const int MIN_DIRWD = 10;        // minimum dirwinwd
 
 // Golly uses wxTimers to control the speed of generating patterns, drawing cells,
@@ -369,6 +360,8 @@ extern wxCursor* curs_cross;        // for selecting cells
 extern wxCursor* curs_hand;         // for moving view by dragging
 extern wxCursor* curs_zoomin;       // for zooming in to a clicked cell
 extern wxCursor* curs_zoomout;      // for zooming out from a clicked cell
+extern wxCursor* curs_wait;         // for indicating a lengthy task is in progress
+extern wxCursor* curs_hidden;       // for hiding cursor when mouse is in overlay
 
 void FreeCursors();
 // deallocate memory allocated by CreateCursors()
