@@ -12,6 +12,7 @@
 
 #include "wxgolly.h"       // for wxGetApp, mainptr
 #include "wxmain.h"        // for mainptr->...
+#include "wxview.h"        // for viewptr->...
 #include "wxprefs.h"       // for namedrules, gollydir, showalgohelp, etc
 #include "wxutils.h"       // for Warning, Fatal, Beep
 #include "wxlayer.h"       // for currlayer
@@ -186,6 +187,20 @@ void AlgoHelp::OnLinkClicked(const wxHtmlLinkInfo& link)
             }
         }
         
+    } else if ( url.StartsWith(wxT("edit:")) ) {
+        // open clicked file in user's preferred text editor
+        wxString path = url.AfterFirst(':');
+#ifdef __WXMSW__
+        path.Replace(wxT("/"), wxT("\\"));
+#endif
+        wxFileName fname(path);
+        if (!fname.IsAbsolute()) path = gollydir + path;
+        mainptr->EditFile(path);
+        
+    } else if ( url.StartsWith(wxT("prefs:")) ) {
+        // user clicked on link to Preferences dialog
+        mainptr->ShowPrefsDialog( url.AfterFirst(':') );
+        
     } else {
         // assume it's a link to a local target or another help file
         DisplayFile(url);
@@ -1057,7 +1072,9 @@ bool ChangeRule()
     wxString oldrule = wxString(currlayer->algo->getrule(),wxConvLocal);
     
     RuleDialog dialog( wxGetApp().GetTopWindow() );
-    if ( dialog.ShowModal() == wxID_OK ) {
+    int button = dialog.ShowModal();
+    viewptr->ResetMouseDown();
+    if (button == wxID_OK) {
         // TransferDataFromWindow has changed the current rule,
         // and possibly the current algorithm as well
         return true;
