@@ -64,7 +64,7 @@ const int maxcomments = 128 * 1024; // maximum comment size
 
 void DoAutoUpdate()
 {
-    if (autoupdate) {
+    if (autoupdate && !mainptr->IsIconized()) {
         inscript = false;
         mainptr->UpdatePatternAndStatus(true);  // call Update()
         if (showtitle) {
@@ -319,7 +319,7 @@ const char* GSF_setrule(const char* rulestring)
     }
     
     // check if the rule string changed, or the number of states changed
-    // (the latter might happen if user edited a table/tree file)
+    // (the latter might happen if user edited a .rule file)
     wxString newrule = wxString(currlayer->algo->getrule(),wxConvLocal);
     int newmaxstate = currlayer->algo->NumCellStates() - 1;
     if (oldrule != newrule || oldmaxstate != newmaxstate) {
@@ -350,7 +350,7 @@ const char* GSF_setrule(const char* rulestring)
     }
     
     // switch to default colors and icons for new rule (we need to do this even if
-    // oldrule == newrule in case there's a new/changed .colors or .icons file)
+    // oldrule == newrule in case there's a new/changed .rule file)
     UpdateLayerColors();
     
     // pattern or colors or icons might have changed
@@ -1073,7 +1073,7 @@ void GSF_getevent(wxString& event, int get)
     if (get) {
         pass_key_events = true;     // future keyboard events will call PassKeyToScript
         pass_mouse_events = true;   // future mouse events will call PassClickToScript
-        pass_file_events = true;    // future open file evenst will call PassFileToScript
+        pass_file_events = true;    // future open file events will call PassFileToScript
         
         // rle3path is non-empty if Golly has just seen a .rle3 file and started up 3D.lua
         if (rle3path[0]) {
@@ -1339,6 +1339,8 @@ void GSF_dokey(const char* ascii)
 
 void GSF_update()
 {
+    if (mainptr->IsIconized()) return;
+
     // update viewport, status bar, and possibly other bars
     inscript = false;
     
@@ -1443,9 +1445,6 @@ void CheckScriptError(const wxString& ext)
             scripterr.Replace(wxT("  File \"<string>\", line 1, in ?\n"), wxT(""));
         }
         Beep();
-        #ifdef __WXMAC__
-            wxSetCursor(*wxSTANDARD_CURSOR);
-        #endif
         wxMessageBox(scripterr, errtype, wxOK | wxICON_EXCLAMATION, wxGetActiveWindow());
     }
     
