@@ -1,26 +1,5 @@
-/*** /
- 
- This file is part of Golly, a Game of Life Simulator.
- Copyright (C) 2013 Andrew Trevorrow and Tomas Rokicki.
- 
- This program is free software; you can redistribute it and/or
- modify it under the terms of the GNU General Public License
- as published by the Free Software Foundation; either version 2
- of the License, or (at your option) any later version.
- 
- This program is distributed in the hope that it will be useful,
- but WITHOUT ANY WARRANTY; without even the implied warranty of
- MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- GNU General Public License for more details.
- 
- You should have received a copy of the GNU General Public License
- along with this program; if not, write to the Free Software
- Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
- 
- Web site:  http://sourceforge.net/projects/golly
- Authors:   rokicki@gmail.com  andrew@trevorrow.com
- 
- / ***/
+// This file is part of Golly.
+// See docs/License.html for the copyright notice.
 
 #ifndef _WXSCRIPT_H_
 #define _WXSCRIPT_H_
@@ -31,28 +10,53 @@ extern bool inscript;
 // Is a script currently running?  We allow access to this flag
 // so clients can temporarily save and restore its setting.
 
-extern bool passkeys;
-extern bool passclicks;
-// Pass keyboard and/or mouse events to script?  Both flags are initially false
-// at the start of a script; both become true if the script calls getevent.
-// If the script calls getkey (deprecated) then only passkeys becomes true.
+extern bool pass_key_events;
+extern bool pass_mouse_events;
+extern bool pass_file_events;
+// Pass keyboard/mouse/file events to script?  All flags are initially false
+// at the start of a script; all become true if the script calls getevent().
+// If the script calls getkey (deprecated) then only pass_key_events becomes true.
 
-extern bool canswitch;
-// Can user switch layers while a script is running?
-
-extern bool stop_after_script;
-// Stop generating pattern after running script?
+extern bool canswitch;          // can user switch layers while a script is running?
+extern bool stop_after_script;  // stop generating pattern after running script?
+extern bool autoupdate;         // update display after changing current universe?
+extern bool allowcheck;         // allow event checking?
+extern bool showprogress;       // script can display the progress dialog?
+extern wxString scripterr;      // error message
+extern wxString mousepos;       // current mouse position
+extern wxString scripttitle;    // window title set by settitle command
+extern wxString rle3path;       // path of .rle3 file to be sent to 3D.lua
 
 void RunScript(const wxString& filename);
 // Run the given script.
 
+void PassOverlayClickToScript(int ox, int oy, int button, int modifiers);
+// Called if a script is running and user clicks mouse in overlay
+// at the given pixel location.
+
 void PassClickToScript(const bigint& x, const bigint& y, int button, int modifiers);
-// Called if a script is running and user clicks mouse.
+// Called if a script is running and user clicks mouse in grid
+// at the given cell location.
+
+void PassMouseUpToScript(int button);
+// Called if a script is running and user releases a mouse button.
+
+void PassZoomInToScript(int x, int y);
+// Called if a script is running and mouse wheel is used to zoom in.
+
+void PassZoomOutToScript(int x, int y);
+// Called if a script is running and mouse wheel is used to zoom out.
 
 void PassKeyToScript(int key, int modifiers = 0);
 // Called if a script is running and user hits a key.
 // Can also be used to abort a script by passing WXK_ESCAPE.
 
+void PassKeyUpToScript(int key);
+// Called if a script is running and user releases a key.
+
+void PassFileToScript(const wxString& filepath);
+// Called if a script is running and user opens a file.
+
 void ShowTitleLater();
 // Called if a script is running and window title has changed.
 
@@ -72,13 +76,6 @@ void SavePendingChanges(bool checkgenchanges = true);
 void FinishScripting();
 // Called when app quits to abort a running script.
 
-// Following are used in wxlua/wxperl/wxpython.cpp:
-
-extern bool autoupdate;       // update display after changing current universe?
-extern bool allowcheck;       // allow event checking?
-extern wxString scripterr;    // error message
-extern wxString mousepos;     // current mouse position
-
 const char abortmsg[] = "GOLLY: ABORT SCRIPT";
 // special message used to indicate that the script was aborted
 
@@ -91,6 +88,7 @@ const char* GSF_open(const wxString& filename, int remember);
 const char* GSF_save(const wxString& filename, const char* format, int remember);
 const char* GSF_setdir(const char* dirname, const wxString& newdir);
 const char* GSF_getdir(const char* dirname);
+const char* GSF_os();
 const char* GSF_setalgo(const char* algostring);
 const char* GSF_setrule(const char* rulestring);
 const char* GSF_setgen(const char* genstring);
@@ -112,5 +110,7 @@ char GSF_getkey();
 void GSF_dokey(const char* ascii);
 void GSF_update();
 void GSF_exit(const wxString& errmsg);
+const char* GSF_getpath();
+const char* GSF_getinfo();
 
 #endif
