@@ -1,26 +1,5 @@
-/*** /
- 
- This file is part of Golly, a Game of Life Simulator.
- Copyright (C) 2013 Andrew Trevorrow and Tomas Rokicki.
- 
- This program is free software; you can redistribute it and/or
- modify it under the terms of the GNU General Public License
- as published by the Free Software Foundation; either version 2
- of the License, or (at your option) any later version.
- 
- This program is distributed in the hope that it will be useful,
- but WITHOUT ANY WARRANTY; without even the implied warranty of
- MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- GNU General Public License for more details.
- 
- You should have received a copy of the GNU General Public License
- along with this program; if not, write to the Free Software
- Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
- 
- Web site:  http://sourceforge.net/projects/golly
- Authors:   rokicki@gmail.com  andrew@trevorrow.com
- 
- / ***/
+// This file is part of Golly.
+// See docs/License.html for the copyright notice.
 
 #include "wx/wxprec.h"     // for compilers that support precompilation
 #ifndef WX_PRECOMP
@@ -210,6 +189,8 @@ typedef enum {
     rotatepattcw,        // pattern was rotated clockwise
     rotatepattacw,       // pattern was rotated anticlockwise
     namechange,          // layer name was changed
+    scriptstart,         // later changes were made by script
+    scriptfinish,        // earlier changes were made by script
     
     // WARNING: code in UndoChange/RedoChange assumes only changes < selchange
     // can alter the layer's dirty state; ie. the olddirty/newdirty flags are
@@ -219,9 +200,7 @@ typedef enum {
     genchange,           // pattern was generated
     setgen,              // generation count was changed
     rulechange,          // rule was changed
-    algochange,          // algorithm was changed
-    scriptstart,         // later changes were made by script
-    scriptfinish         // earlier changes were made by script
+    algochange           // algorithm was changed
 } change_type;
 
 class ChangeNode: public wxObject {
@@ -258,6 +237,7 @@ public:
     int oldexpo, newexpo;                   // old and new step exponents
     StartingInfo* startinfo;                // saves starting info for ResetPattern
     // also uses oldsel, newsel
+    // and oldtempstart, newtempstart
     
     // setgen info
     bigint oldstartgen, newstartgen;        // old and new startgen values
@@ -354,6 +334,9 @@ ChangeNode::~ChangeNode()
 
 void ChangeNode::ChangeCells(bool undo)
 {
+    // avoid possible pattern update during a setcell call (can happen if cellcount is large)
+    viewptr->nopattupdate = true;
+
     // change state of cell(s) stored in cellinfo array
     if (undo) {
         // we must undo the cell changes in reverse order in case
@@ -371,6 +354,8 @@ void ChangeNode::ChangeCells(bool undo)
         }
     }
     if (cellcount > 0) currlayer->algo->endofpattern();
+    
+    viewptr->nopattupdate = false;
 }
 
 // -----------------------------------------------------------------------------
@@ -426,14 +411,16 @@ bool ChangeNode::DoChange(bool undo)
             
         case genchange:
             currlayer->currfile = oldcurrfile;
+            if (startinfo) {
+                // restore starting info for use by ResetPattern
+                startinfo->Restore();
+            }
             if (undo) {
+                currlayer->tempstart = oldtempstart;    // in case script called reset()
                 currlayer->currsel = oldsel;
                 mainptr->RestorePattern(oldgen, oldfile, oldx, oldy, oldmag, oldbase, oldexpo);
             } else {
-                if (startinfo) {
-                    // restore starting info for use by ResetPattern
-                    startinfo->Restore();
-                }
+                currlayer->tempstart = newtempstart;    // in case script called reset()
                 currlayer->currsel = newsel;
                 mainptr->RestorePattern(newgen, newfile, newx, newy, newmag, newbase, newexpo);
             }
@@ -808,8 +795,8 @@ void UndoRedo::RememberGenStart()
 {
     startcount++;
     if (startcount > 1) {
-        // return immediately and ignore next RememberGenFinish call;
-        // this can happen in Linux app if user holds down space bar
+        // return immediately and ignore next RememberGenFinish call
+        // (this probably can't happen any more, but play safe)
         return;
     }
     
@@ -838,7 +825,7 @@ void UndoRedo::RememberGenStart()
         // we can just reset to starting pattern
         prevfile = wxEmptyString;
     } else {
-        // save starting pattern in a unique temporary file
+        // save current pattern in a unique temporary file
         prevfile = wxFileName::CreateTempFileName(tempdir + genchange_prefix);
         
         // if head of undo list is a genchange node then we can copy that
@@ -887,11 +874,19 @@ void UndoRedo::RememberGenFinish()
         prevfile = wxEmptyString;
         return;
     }
+
+    // currlayer->tempstart will need to change if script calls reset()
+    wxString oldtempstart = currlayer->tempstart;
     
     wxString fpath;
     if (currlayer->algo->getGeneration() == currlayer->startgen) {
-        // this can happen if script called reset() so just use starting pattern
+        // script called reset() so just use starting pattern
         fpath = wxEmptyString;
+
+        // if script generates pattern then tempstart will be clobbered by
+        // SaveStartingPattern, so change currlayer->tempstart to a new temporary file
+        currlayer->tempstart = wxFileName::CreateTempFileName(tempdir + wxT("gr_"));
+
     } else {
         // save finishing pattern in a unique temporary file
         fpath = wxFileName::CreateTempFileName(tempdir + genchange_prefix);
@@ -923,6 +918,8 @@ void UndoRedo::RememberGenFinish()
     change->newexpo = currlayer->currexpo;
     change->oldsel = prevsel;
     change->newsel = currlayer->currsel;
+    change->oldtempstart = oldtempstart;
+    change->newtempstart = currlayer->tempstart;
 
     // also remember the file containing the starting pattern
     // (in case it is changed by by RememberSetGen or RememberNameChange)
@@ -961,7 +958,7 @@ void UndoRedo::AddGenChange()
     prevexpo = currlayer->startexpo;
     prevfile = wxEmptyString;
     
-    // play safe and pretend RememberGenStart was called
+    // pretend RememberGenStart was called
     startcount = 1;
     
     // avoid RememberGenFinish returning early if inscript is true
@@ -976,6 +973,9 @@ void UndoRedo::AddGenChange()
 
 void UndoRedo::SyncUndoHistory()
 {
+    // reset startcount for the next RememberGenStart call
+    startcount = 0;
+
     // synchronize undo history due to a ResetPattern call;
     // wind back the undo list to just past the genchange node that
     // matches the current layer's starting gen count
@@ -1010,6 +1010,7 @@ void UndoRedo::SyncUndoHistory()
             return;
         }
     }
+    
     // should never get here
     Warning(_("Bug detected in SyncUndoHistory!"));
 }
@@ -1252,6 +1253,9 @@ void UndoRedo::RememberScriptStart()
     
     change->suffix = _("Script Changes");
     
+    // remmember dirty flag at start of script
+    change->olddirty = currlayer->dirty;
+    
     undolist.Insert(change);
     
     // update Undo action and clear Redo action
@@ -1294,6 +1298,9 @@ void UndoRedo::RememberScriptFinish()
     
     change->suffix = _("Script Changes");
     
+    // remmember dirty flag at end of script
+    change->newdirty = currlayer->dirty;
+    
     undolist.Insert(change);
     
     // update Undo item in Edit menu
@@ -1324,6 +1331,19 @@ bool UndoRedo::CanRedo()
 
 // -----------------------------------------------------------------------------
 
+static void ChangeDirtyFlag(bool newdirty)
+{
+    // change dirty flag to newdirty, update window title and Layer menu items
+    if (newdirty) {
+        currlayer->dirty = false;   // make sure it changes to true
+        MarkLayerDirty();
+    } else {
+        MarkLayerClean(currlayer->currname);
+    }
+}
+
+// -----------------------------------------------------------------------------
+
 void UndoRedo::UndoChange()
 {
     if (!CanUndo()) return;
@@ -1348,6 +1368,8 @@ void UndoRedo::UndoChange()
         undolist.Erase(node);
         redolist.Insert(change);
         
+        bool dirty_at_end = change->newdirty;
+        
         while (change->changeid != scriptstart) {
             // call UndoChange recursively; temporarily set doingscriptchanges so
             // 1) UndoChange won't return if DoChange is aborted
@@ -1360,6 +1382,12 @@ void UndoRedo::UndoChange()
             if (node == NULL) Fatal(_("Bug in UndoChange!"));
             change = (ChangeNode*) node->GetData();
         }
+        
+        // update dirty flag if it was changed by script
+        if (change->olddirty != dirty_at_end) {
+            ChangeDirtyFlag(change->olddirty);
+        }
+        
         mainptr->UpdatePatternAndStatus();
         // continue below so that scriptstart node is removed from undo list
         // and added to redo list
@@ -1367,21 +1395,15 @@ void UndoRedo::UndoChange()
     } else {
         // user might abort the undo (eg. a lengthy rotate/flip)
         if (!change->DoChange(true) && !doingscriptchanges) return;
+        
+        if (!doingscriptchanges && change->changeid < selchange && change->olddirty != change->newdirty) {
+            ChangeDirtyFlag(change->olddirty);
+        }
     }
     
     // remove node from head of undo list (doesn't delete node's data)
     undolist.Erase(node);
     
-    if (change->changeid < selchange && change->olddirty != change->newdirty) {
-        // change dirty flag, update window title and Layer menu items
-        if (change->olddirty) {
-            currlayer->dirty = false;  // make sure it changes
-            MarkLayerDirty();
-        } else {
-            MarkLayerClean(currlayer->currname);
-        }
-    }
-    
     // add change to head of redo list
     redolist.Insert(change);
     
@@ -1417,6 +1439,8 @@ void UndoRedo::RedoChange()
         redolist.Erase(node);
         undolist.Insert(change);
         
+        bool dirty_at_start = change->olddirty;
+        
         while (change->changeid != scriptfinish) {
             // call RedoChange recursively; temporarily set doingscriptchanges so
             // 1) RedoChange won't return if DoChange is aborted
@@ -1429,6 +1453,12 @@ void UndoRedo::RedoChange()
             if (node == NULL) Fatal(_("Bug in RedoChange!"));
             change = (ChangeNode*) node->GetData();
         }
+        
+        // update dirty flag if it was changed by script
+        if (change->newdirty != dirty_at_start) {
+            ChangeDirtyFlag(change->newdirty);
+        }
+        
         mainptr->UpdatePatternAndStatus();
         // continue below so that scriptfinish node is removed from redo list
         // and added to undo list
@@ -1436,21 +1466,15 @@ void UndoRedo::RedoChange()
     } else {
         // user might abort the redo (eg. a lengthy rotate/flip)
         if (!change->DoChange(false) && !doingscriptchanges) return;
+        
+        if (!doingscriptchanges && change->changeid < selchange && change->olddirty != change->newdirty) {
+            ChangeDirtyFlag(change->newdirty);
+        }
     }
     
     // remove node from head of redo list (doesn't delete node's data)
     redolist.Erase(node);
     
-    if (change->changeid < selchange && change->olddirty != change->newdirty) {
-        // change dirty flag, update window title and Layer menu items
-        if (change->newdirty) {
-            currlayer->dirty = false;  // make sure it changes
-            MarkLayerDirty();
-        } else {
-            MarkLayerClean(currlayer->currname);
-        }
-    }
-    
     // add change to head of undo list
     undolist.Insert(change);
     
