@@ -33,18 +33,17 @@
 void Note(const wxString& msg, bool showCancel)
 {
     wxString title = wxGetApp().GetAppName() + _(" note:");
-#ifdef __WXMAC__
-    wxSetCursor(*wxSTANDARD_CURSOR);
-#endif
     if (inscript && showCancel) {
         // add a Cancel button so user can abort script
         int button = wxMessageBox(msg, title, wxOK | wxCANCEL | wxICON_INFORMATION,
                                   wxGetActiveWindow());
+        viewptr->ResetMouseDown();
         if (button == wxCANCEL) {
             PassKeyToScript(WXK_ESCAPE);     // abort script
         }
     } else {
         wxMessageBox(msg, title, wxOK | wxICON_INFORMATION, wxGetActiveWindow());
+        viewptr->ResetMouseDown();
     }
 }
 
@@ -54,18 +53,17 @@ void Warning(const wxString& msg, bool showCancel)
 {
     Beep();
     wxString title = wxGetApp().GetAppName() + _(" warning:");
-#ifdef __WXMAC__
-    wxSetCursor(*wxSTANDARD_CURSOR);
-#endif
     if (inscript && showCancel) {
         // add a Cancel button so user can abort script
         int button = wxMessageBox(msg, title, wxOK | wxCANCEL | wxICON_EXCLAMATION,
                                   wxGetActiveWindow());
+        viewptr->ResetMouseDown();
         if (button == wxCANCEL) {
             PassKeyToScript(WXK_ESCAPE);     // abort script
         }
     } else {
         wxMessageBox(msg, title, wxOK | wxICON_EXCLAMATION, wxGetActiveWindow());
+        viewptr->ResetMouseDown();
     }
 }
 
@@ -75,10 +73,8 @@ void Fatal(const wxString& msg)
 {
     Beep();
     wxString title = wxGetApp().GetAppName() + _(" error:");
-#ifdef __WXMAC__
-    wxSetCursor(*wxSTANDARD_CURSOR);
-#endif
     wxMessageBox(msg, title, wxOK | wxICON_ERROR, wxGetActiveWindow());
+    viewptr->ResetMouseDown();
     
     exit(1);    // safer than calling wxExit()
 }
@@ -165,7 +161,9 @@ bool GetString(const wxString& title, const wxString& prompt,
                const wxString& instring, wxString& outstring)
 {
     StringDialog dialog(wxGetApp().GetTopWindow(), title, prompt, instring);
-    if ( dialog.ShowModal() == wxID_OK ) {
+    int button = dialog.ShowModal();
+    viewptr->ResetMouseDown();
+    if (button == wxID_OK) {
         outstring = dialog.GetValue();
         return true;
     } else {
@@ -333,7 +331,9 @@ bool GetInteger(const wxString& title, const wxString& prompt,
 {
     IntegerDialog dialog(wxGetApp().GetTopWindow(), title, prompt,
                          inval, minval, maxval);
-    if ( dialog.ShowModal() == wxID_OK ) {
+    int button = dialog.ShowModal();
+    viewptr->ResetMouseDown();
+    if (button == wxID_OK) {
         *outval = dialog.GetValue();
         return true;
     } else {
@@ -352,10 +352,10 @@ int SaveChanges(const wxString& query, const wxString& msg)
     wxMessageDialog dialog(wxGetActiveWindow(), msg, query,
                            wxCENTER | wxNO_DEFAULT | wxYES_NO | wxCANCEL |
                            wxICON_INFORMATION);
-    
     dialog.SetYesNoCancelLabels("Cancel", "Save", "Don't Save");
-    
-    switch ( dialog.ShowModal() ) {
+    int button = dialog.ShowModal();
+    viewptr->ResetMouseDown();
+    switch (button) {
         case wxID_YES:    return 0;    // Cancel
         case wxID_NO:     return 2;    // Save
         case wxID_CANCEL: return 1;    // Don't Save
@@ -366,6 +366,7 @@ int SaveChanges(const wxString& query, const wxString& msg)
     int answer = wxMessageBox(msg, query,
                               wxICON_QUESTION | wxYES_NO | wxCANCEL,
                               wxGetActiveWindow());
+    viewptr->ResetMouseDown();
     switch (answer) {
         case wxYES: return 2;
         case wxNO:  return 1;
@@ -437,9 +438,6 @@ void BeginProgress(const wxString& dlgtitle)
     // avoid cursor flickering if this is called during a script
     if (!inscript) {
         // let user know they'll have to wait
-#ifdef __WXMAC__
-        wxSetCursor(*wxHOURGLASS_CURSOR);
-#endif
         if (mainptr->infront) viewptr->SetCursor(*wxHOURGLASS_CURSOR);
     }
 }
