@@ -95,6 +95,9 @@ public:
     void ProcessClick(int x, int y, int button, int modifiers);
     void ProcessClickedControl();
     
+    void ResetMouseDown();
+    // modal dialogs need to reset mouseisdown to false
+    
     // data
     bool waitingforclick;         // waiting for paste click?
     bool drawingcells;            // drawing cells due to dragging mouse?
@@ -102,6 +105,8 @@ public:
     bool movingview;              // moving view due to dragging mouse?
     bool nopattupdate;            // disable pattern updates?
     bool showcontrols;            // draw translucent controls?
+    bool mouseisdown;             // mouse button held down?
+    int whichbuttondown;          // which mouse button is down
     wxRect controlsrect;          // location of translucent controls
     wxRect pasterect;             // area to be pasted
     wxCursor* oldcursor;          // non-NULL if shift key has toggled cursor
